#!/opt/edge/venv/bin/python3.11

from edge import eventlog
from edge.support import fs
from edge.types.exceptions import *
from edge.webserver import cgi


class _HandlerFactory:
    """
    GET   /api/v2/sys/conf/nls   /<file>
    """

    @classmethod
    def create(cls, request: cgi.CgiRequest) -> cgi.CgiHandler:
        method_to_handlers_map: cgi.CgiHandlerFactoryDict = {
            'GET': [
                cls._nls__get_file
            ]
        }

        handlers = method_to_handlers_map.get(request.method, [])
        for handler in handlers:
            try:
                return handler(request)

            except cgi.CgiError404:
                pass

        eventlog.log_d('fail: http404')
        raise cgi.CgiError404

    @classmethod
    def _nls__get_file(cls, request: cgi.CgiRequest) -> cgi.CgiHandler:
        if len(request.path_info) != 1:
            raise cgi.CgiError404

        request.assert_query_absent()
        request.assert_body_absent()

        def handler() -> cgi.CgiResponse:
            nls_path = fs.join_path('/opt/edge/share/setupstore/nls', request.path_info[0])
            nls_jnode = fs.load_json3(nls_path, default=None)
            if nls_jnode is None:
                eventlog.log_d('fail: NotFoundError')
                raise NotFoundError

            return cgi.CgiResponse.create200(nls_jnode)

        return handler


if __name__ == '__main__':
    eventlog.open_log('cgi-nls', 'debug')
    try:
        cgi.cgi_handle(_HandlerFactory.create)
    finally:
        eventlog.close_log()
